==> haskell-prettyclass-1.0.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyclass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyclass
version:              1.0.0.0
visibility:           public
id:                   prettyclass-1.0.0.0-FLpKvWUSyBT10zZio3rFtI
key:                  prettyclass-1.0.0.0-FLpKvWUSyBT10zZio3rFtI
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             Pretty printing class similar to Show.
description:
    Pretty printing class similar to Show, based on the HughesPJ
    pretty printing library.  Provides the pretty printing class
    and instances for the Prelude types.

category:             Text
abi:                  f87a13366d5951a17317699455ba003d
exposed:              True
exposed-modules:      Text.PrettyPrint.HughesPJClass
import-dirs:          /usr/lib/ghc-9.0.1/site-local/prettyclass-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/prettyclass-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/prettyclass-1.0.0.0
hs-libraries:         HSprettyclass-1.0.0.0-FLpKvWUSyBT10zZio3rFtI
depends:              base-4.15.0.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-prettyclass/html/prettyclass.haddock
haddock-html:         /usr/share/doc/haskell-prettyclass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyclass-1.0.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyclass.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyclass
version:              1.0.0.0
visibility:           public
id:                   prettyclass-1.0.0.0-AJqrHIdddTvAkVxD2LfKcX
key:                  prettyclass-1.0.0.0-AJqrHIdddTvAkVxD2LfKcX
license:              BSD-3-Clause
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            experimental
synopsis:             Pretty printing class similar to Show.
description:
    Pretty printing class similar to Show, based on the HughesPJ
    pretty printing library.  Provides the pretty printing class
    and instances for the Prelude types.

category:             Text
abi:                  1b44767ef3dd2e56e928944da2632862
exposed:              True
exposed-modules:      Text.PrettyPrint.HughesPJClass
import-dirs:          /usr/lib/ghc-9.0.2/site-local/prettyclass-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/prettyclass-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/prettyclass-1.0.0.0
hs-libraries:         HSprettyclass-1.0.0.0-AJqrHIdddTvAkVxD2LfKcX
depends:              base-4.15.1.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-prettyclass/html/prettyclass.haddock
haddock-html:         /usr/share/doc/haskell-prettyclass/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
